==> haskell-topograph-1.0.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 topograph
version:              1.0.1
visibility:           public
id:                   topograph-1.0.1-IrOC8BF2AgAAAf0xrJhWWU
key:                  topograph-1.0.1-IrOC8BF2AgAAAf0xrJhWWU
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  51f6637a84549129a2b1ab914bd7b74b
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.4.8/site-local/topograph-1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/topograph-1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/topograph-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-topograph
hs-libraries:         HStopograph-1.0.1-IrOC8BF2AgAAAf0xrJhWWU
depends:
    base-4.17.2.1 base-orphans-0.9.3-JT0HAQbbOJV5hOgWUnXcwi
    containers-0.6.7 vector-0.13.2.0-ALyKXv7XVpOIl9EVBdgwIc

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-topograph-1.0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 topograph
version:              1.0.1
visibility:           public
id:                   topograph-1.0.1-95GGTrCYAJa19pAfN03sL9
key:                  topograph-1.0.1-95GGTrCYAJa19pAfN03sL9
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  6df3552b0e95d6a74ba0cff29fc1e67c
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.4.8/site-local/topograph-1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/topograph-1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/topograph-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-topograph
hs-libraries:         HStopograph-1.0.1-95GGTrCYAJa19pAfN03sL9
depends:
    base-4.17.2.1 base-orphans-0.9.3-3TK7PbmMe6S5e7cKTNEuPm
    containers-0.6.7 vector-0.13.2.0-EQFZws9ZIK8A2ESM3MR23n

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
